# neo-cli

[![Gitter](https://badges.gitter.im/BiznetGIO/neo-cli.svg)](https://gitter.im/BiznetGIO/neo-cli?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![image](https://img.shields.io/pypi/v/neo-cli.svg)](https://pypi.org/project/neo-cli/)
[![image](https://img.shields.io/pypi/l/neo-cli.svg)](https://pypi.org/project/neo-cli/)
[![image](https://img.shields.io/pypi/pyversions/neo-cli.svg)](https://pypi.org/project/neo-cli/)
[![Build Status](https://travis-ci.org/BiznetGIO/neo-cli.svg?branch=master)](https://travis-ci.org/BiznetGIO/neo-cli)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

Don't let all those templates and commands burden your head. Sit back,
relax and let `neo-cli` asks what you need.

## What is neo-cli ?

`neo-cli` lower the barrier of understanding complicated templates,
memorizing long command and parameters to create your cloud
infrastructure. `neo` will interactively ask what you need.

In addition, `neo-cli` aims to support diverse cloud platforms in near
future. So no matter what your cloud platforms is, `neo-cli` will always be
your friend.

Watch `neo-cli` in [action](https://asciinema.org/a/164200)


![neo](/docs/img/neo.gif)

## Installation

Install and update using  [pip](https://pip.pypa.io/en/stable/quickstart/)

At the time neo-cli only support Python3 or newer.

``` bash
pip3 install -U neo-cli
```

# Documentation

Documentation is available at <https://biznetgio.github.io/neo-cli/>
